<?php
// Software released under the General Public License (version 2 or later), available at
// http://www.gnu.org/copyleft/gpl.html
//********************************************************************************

//require_once($tmp . 'spacetime/SpaceConstants.php');
//require_once($tmp . 'spacetime/CoordsConstants.php');

/**
Contains constants designating frames used in the solar system.

@license  GPL
@author   <a href="http://www.tig12.net">Thierry Graff</a>
@history 2007.02.26 : php5 port from jephem.astro.spacetime.SpaceConstants.java
@history 2001 : Creation from a part of jephem.astro.Body.java.
****************************************************************************************/
interface SolarFramesConstants{

  /** Constant indicating that a coordinate is expressed in the frame
  of the theory used to compute it. */
  const THEORY = 0;

  /** Constant designating heliocentric ecliptic reference frame,
  for geometric coordinates. */
  const EC_HELIO_GEOMETRIC = 1;
  const HELIO = 1;

  /** Constant designating geocentric ecliptic reference frame ;
  coordinates expressed in this frame are <B>true apparent coordinates</B>.
  <br/>Reference system : FK5.
  <br/>Reference plane = mean ecliptic of date.
  <br/>Equinox = true equinox of date.
  */
  const ECLIPTIC = 2;
  const EC = 2;

  /** Constant designating geocentric equatorial reference frame ;
  coordinates expressed in this frame are <B>true apparent coordinates</B>.
  <br/>Reference system : FK5.
  <br/>Reference plane = true equator of date.
  <br/>Equinox = true equinox of date.
  */
  const EQUATORIAL = 3;
  const EQ = 3;

  /** Constant designating equatorial topocentric reference frame. */
//  const EQUATORIAL_TOPOCENTRIC = 4;

  /** Constant designating horizontal topocentric reference frame. */
  const HORIZONTAL_TOPOCENTRIC = 5;

  /** Constant designating galactic reference frame. */
  const GALACTIC = 6;

}// end SolarFramesConstants
?>