<?php
// Software released under the General Public License (version 2 or later), available at
// http://www.gnu.org/copyleft/gpl.html

require_once("libext/utils/maths/uMaths.php");

/****************************************************************************************
Contains functions that should be put elsewhere...

@license  GPL
@author   <a href="http://www.tig12.net">Thierry Graff</a>
@history 2002.10.30 : Creation
****************************************************************************************/

class SolarSystemHelper{

  //********************* keplerEq ******************************
	/**
    Computation of the eccentric anomaly from eccentricity and mean anomaly.
    @param $e Eccentricity.
    @param $M Mean anomaly.
    @return Eccentric anomaly.
  */
  public static function keplerEq($e, $M){
    $ct = 0;
    $u_p = 0;
    $u = $M;
    $precision = 0.0000000000001;
    while (abs($u - $u_p) > $precision){
      $u_p = $u;
      $u = $M + $e * sin($u);
      $ct++;
      if ($ct > 25){
    	 $precision = $precision * 2;
    	 $ct = 0;
      }
    }
    return $u;
  }// end keplerEq
  
  
  //********************* lmst ******************************
	/**
    Computes the Local Mean Sideral Time, in decimal hours or decimal degrees.
    The result is reduced in [0, 24[ or [0, 360[.
    From Meeus, Astronomical Algorithms, 2nd edition, formula 12.4.
    @param $jd The juilan date.
    @param $long The longitude of the place, in degrees, measured positively esatwards from Greenwich.
    @param $format Indicates if the result should be returned in hours or degrees. Can be "H" or "D".
  */
  public static function lmst($jd, $long, $format="H"){
    $T = ($jd - 2451545.0)/36525; // julian centuries since 2000.01.01, 12h UT1.
    $gmst = 280.46061837
          + (13185000.77005374225 + (0.000387933 - 2.5833118057e-8*$T)*$T)*$T; // in degrees
    if($format == "H") return uMaths::modX(($gmst + $long)/15, 24);
    else               return uMaths::mod360($gmst + $long);
  }// end lmst
  
  
  //********************* obliq ******************************
	/** Computes the obliquity of the equinox.
  <br/>Formula from Meeus' old book.
  @param $jd The juilan date.
  */
  public static function obliq($jd){
    $T = ($jd - 2415020)/36525; // julian centuries since 1900.01.01, 12h.
  	return 23.452294 + (-0.0130125 + (-0.00000164 + 0.000000503*$T)*$T)*$T;
  }// end obliq
  
  
}// end class SolarSystemHelper
?>