<?php
// Software released under the General Public License (version 2 or later), available at
// http://www.gnu.org/copyleft/gpl.html
/********************************************************************************
Interface to be implemented by ephemeris engines
Permits to ensure class {@link Ephemeris} that its eval'ed code will be understood

@license      GPL
@author   <a href="http://www.tig12.net">Thierry Graff</a>
@history      2007.12.09 : creation.
*********************************************************************************/

interface EphemerisEngine{

  
  //********************* compute ********************* 
  /** 
    Perform ephemeris computation.
    @param $jd Julian day of the computation
    @param $what Mixed What should be computed
                  Can be a constant or an array of constants
    @param $options Associative array of key / value pairs ; supported keys depend on the implementation
    @return An associative array :
                  - The keys are constants defined in JeTheme interfaces (SolarSystemConstants, DomificationConstants etc.)
                  - The values are the values of this parameter for this julian day
                  ex : $result[SolarSystemConstants::JUPITER]
                  Coordinate(s) are returned in associative array (keys : x0, x1, x2)
                  For example, to get the longitude of the sun : <code>$result[SolarSystemConstants::SUN]['x1']</code>
  */
  public static function compute($jd, $what, $options=array());
  
  /* 
  public static function getAvailablePlanets();
  
  public static function getAvailableFrames();
  
  public static function getPrecision($planet, $jd);
  */
  
}// end
?>