<?php 
// Software released under the General Public License (version 2 or later), available at
// See file licence.txt or at http://www.gnu.org/copyleft/gpl.html
/****************************************************************************************
Adds functionalities to php function <code>parse_ini_file()</code>

@license  GPL
@author   <a href="http://www.tig12.net">Thierry Graff</a>
@history 2007.06.12 : Creation
@history 2008.02.18 : Transformed function to a class
****************************************************************************************/

class uIniFile{
  
  //******************** parse_ini_file *******************************
  /**
    Equivalent to php function <code>parse_ini_file()</code>, but the ini file can have C-like comments.
    @throws Exception : a temporary file is needed during execution ;
                   an exception is thrown if this file can't be written on disk.
  */
  public static function parse_ini_file($fileName, $sections=false){
    $str = @file_get_contents($fileName);
    if(!$str) throw new Exception("I/O problem : Impossible to open file <b>$fileName</b>");
    // remove "//" comments
    $str = preg_replace('#//.*$#m', '', $str);
    // remove "/* ... */" comments
    $str = preg_replace('#/\*.*?\*/#s', '', $str);
    if(!@file_put_contents('tmp_parseinifile', $str)) throw new Exception("I/O problem : Impossible to create file <b>tmp_parseinifile</b>");
    $array = parse_ini_file('tmp_parseinifile', $sections);
    if(!@unlink('tmp_parseinifile')) throw new Exception("I/O problem : Impossible to remove file <b>tmp_parseinifile</b>");
    return $array;
  }// end parse_ini_file
  
  
  // *************************** parse_ini_string ***************************
  /**
    Equivalent to {@link parseIniFile()}, but parses a string instead of a file 
    @throws Exception : a temporary file is needed during execution ;
                 an exception is thrown if this file can't be written on disk.
  */
  public static function parse_ini_string($str, $sections){
    if(!@file_put_contents('tmp_parseinistring', $str)) throw new Exception("I/O problem : Impossible to create file <b>tmp_parseinistring</b>");
    $array = self::parse_ini_file('tmp_parseinistring', $sections);
    if(!@unlink('tmp_parseinistring')) throw new Exception("I/O problem : Impossible to remove file <b>tmp_parseinistring</b>");
    return $array;
  }// end parse_ini_string
  
}// end class
?>