<?php
// Software released under the General Public License (version 2 or later), available at
// http://www.gnu.org/copyleft/gpl.html
/****************************************************************************************
Contains constants related to coordinates used in the solar system.

@license  GPL
@author   <a href="http://www.tig12.net">Thierry Graff</a>
@history 2002.10.30 : Creation
@history 200.12.14 : PHP5 port from JEphem
****************************************************************************************/

interface CoordinateConstants{
  
  /** Constant designating the first spatial coordinate (<b>X</b> in cartesian, <b>&rho;</b> in spherical). */
  const COORD_X1 = 'x1';
  /** Constant designating the second spatial coordinate (<b>Y</b> in cartesian, <b>&theta;</b> in spherical). */
  const COORD_X2 = 'x2';
  /** Constant designating the third spatial coordinate (<b>Z</b> in cartesian, <b>&phi;</b> in spherical). */
  const COORD_X3 = 'x3';
  /** Constant designating the first velocity coordinate (<b>dX/dt</b> in cartesian, <b>d&rho;/dt</b> in spherical). */
  const COORD_V1 = 'v1';
  /** Constant designating the second velocity coordinate (<b>dY/dt</b> in cartesian, <b>d&theta/dt</b> in spherical). */
  const COORD_V2 = 'v2';
  /** Constant designating the third velocity coordinate (<b>dZ/dt</b> in cartesian, <b>d&phi;/dt</b> in spherical). */
  const COORD_V3 = 'v3';

  //******************************************************
  // Constants to desingate groups of 3 coordinates.
  // Values used for array purposes ; must be 0, 1, 2 ...
  //******************************************************

  /** Constant designating the "X, Y, Z" group of coordinates.
  <br/><code>labels = {"X", "Y", "Z"}</code>. */
  const COORDGROUP_XYZ = 'xyz';

  /** Constant designating the "delta, beta, lambda" group of coordinates.
  <br/><code>labels = {"del", "bet", "lam"}</code>. */
  const COORDGROUP_DELTA_BETA_LAMBDA = 'delta_beta_lambda';

  /** Constant designating the "r, l, b" group of coordinates.
  <br/><code>labels = {"r", "l", "b"}</code>. */
  const COORDGROUP_RLB = 'rlb';

  /** Constant designating the "distance alpha, delta" group of coordinates.
  <br/><code>labels = {"dist.", "alpha", "beta"}</code>. */
  const COORDGROUP_DIST_ALPHA_DELTA = 'dist_alpha_beta';

  
}// end CoordinateConstants
?>
